@@ -1,35 +1,38 @@
 #' Get database summary
 #'
 #' @description Get a summary of the data stored.
-#' 
+#'
 #' @param triplestore Object of class triplestore_access which manages database
 #' access.
 #'
 #' @return Data frame: Columns: "data type", "value".
-#' 
-#' @examples 
-#' 
-#' triplestore <- triplestore_access$new()
-#' 
-#' triplestore$set_access_options(
+#'
+#' @examples
+#'
+#' avidaDB <- triplestore_access$new()
+#'
+#' avidaDB$set_access_options(
 #'   url = "https://graphdb.fortunalab.org",
 #'   user = "public_avida",
 #'   password = "public_avida",
 #'   repository = "avidaDB_test"
 #' )
-#' 
-#' get_db_summary(triplestore)
+#'
+#' get_db_summary(triplestore = avidaDB)
 #'
 #' @export
-#' 
+#'
 get_db_summary <- function(triplestore)
 {
   # Get summary
   abstract <- triplestore$submit_query("PREFIX terms: <http://purl.org/dc/terms/>
                                         PREFIX ONTOAVIDA: <http://purl.obolibrary.org/obo/ONTOAVIDA_>
-                                        select ?abstract where { 
+                                        select ?abstract where {
                                           ONTOAVIDA:11111111 terms:abstract ?abstract .
-                                        }")$abstract
+                                        } ORDER BY DESC(?abstract) LIMIT 1")$abstract
+
+  if (is.null(abstract))
+    return(invisible(NULL))
   
   # Convert to data frame
   df <- data.frame()
@@ -45,6 +48,5 @@ get_db_summary <- function(triplestore)
     }
     colnames(df) <- unlist(strsplit(ul[1], ","))
   }
-  
   return(df)
-}
\ No newline at end of file
+}
