@@ -3,42 +3,42 @@
 #' @description Get the phenotype encoded by the genome of a digital organism that is specified by a unique combination of logic operations.
 #'
 #' @param logic_operation List of logical functions from the following set:
-#' "equals", "exclusive-or", "not-or", "and-not", "or", "orn-not", "and", 
+#' "equals", "exclusive-or", "not-or", "and-not", "or", "orn-not", "and",
 #' "not-and", "not".
-#' 
+#'
 #' @param phenotype_binary Logical value (TRUE/FALSE) to show/hide the phenotype in binary notation (FALSE by default).
-#' 
+#'
 #' @param triplestore Object of class triplestore_access which manages database
 #' access.
-#' 
+#'
 #' @return Data frame. Columns: "phenotype_id", "phenotype_binary" (optional).
-#' 
-#' @examples 
-#' 
+#'
+#' @examples
+#'
 #' # Create triplestore object
-#' triplestore <- triplestore_access$new()
-#' 
+#' avidaDB <- triplestore_access$new()
+#'
 #' # Set access options
-#' triplestore$set_access_options(
+#' avidaDB$set_access_options(
 #'   url = "https://graphdb.fortunalab.org",
 #'   user = "public_avida",
 #'   password = "public_avida",
 #'   repository = "avidaDB_test"
 #' )
-#' 
+#'
 #' # Single logic operation
 #' get_phenotype_id_from_logic_operation(
 #'   logic_operation = "not-or",
-#'   triplestore = triplestore
+#'   triplestore = avidaDB
 #' )
-#' 
+#'
 #' # More than one logic operation
 #' ops <- c("equals", "exclusive or", "not-or", "and-not", "or", "orn-not")
-#' 
+#'
 #' get_phenotype_id_from_logic_operation(
 #'   logic_operation = ops,
 #'   phenotype_binary = TRUE,
-#'   triplestore = triplestore
+#'   triplestore = avidaDB
 #' )
 #'
 #' @export
@@ -72,7 +72,10 @@ get_phenotype_id_from_logic_operation <- function(logic_operation, phenotype_bin
   # Submit query
   response <- triplestore$submit_query(query = query)
 
-  if (nrow(response) > 0) {
+  if (is.null(response))
+    return(invisible(NULL))
+  
+  if (nrow(response)>0) {
     # Remove prefix
     response <- remove_prefix(prefix = ontoavida_prefix(), data = response)
 
